@@ -76,8 +76,8 @@ CONFIGURATION_TIMEOUT = 60
 
 USER_COMMAND_MARK = u'\u200B' * 10
 
-LOG_SIZE = 1000
-
 LOG_SIZE_IN_BYTES = 1024 * 1024
 
+LOG_SIZE_TO_CLEAN = 10 * 1024
+
 DIFF_WITH_ALIAS = 0.5
