@@ -8,10 +8,10 @@ OPTIONS = "^\s*\*\s(.*)"
 
 @for_app('aws')
 def match(command):
-    return "usage:" in command.stderr and "maybe you meant:" in command.stderr
+    return "usage:" in command.output and "maybe you meant:" in command.output
 
 
 def get_new_command(command):
-    mistake = re.search(INVALID_CHOICE, command.stderr).group(0)
-    options = re.findall(OPTIONS, command.stderr, flags=re.MULTILINE)
+    mistake = re.search(INVALID_CHOICE, command.output).group(0)
+    options = re.findall(OPTIONS, command.output, flags=re.MULTILINE)
     return [replace_argument(command.script, mistake, o) for o in options]
